@@ -23,6 +23,8 @@
 #' @inheritParams rope
 #' @inheritParams hdi
 #'
+#' @inheritSection hdi Model components
+#'
 #' @return Values between 0 and 1 corresponding to the probability of practical significance (ps).
 #'
 #' @details `p_significance()` returns the proportion of a probability
@@ -227,8 +229,12 @@ p_significance.mcmc <- function(x, threshold = "default", ...) {
 
 
 #' @export
-p_significance.bamlss <- function(x, threshold = "default", component = c("all", "conditional", "location"), ...) {
-  out <- p_significance(insight::get_parameters(x, component = component), threshold = threshold, ...)
+p_significance.bamlss <- function(x, threshold = "default", component = "all", ...) {
+  out <- p_significance(
+    insight::get_parameters(x, component = component),
+    threshold = threshold,
+    ...
+  )
   out <- .add_clean_parameters_attribute(out, x)
   out
 }
@@ -280,18 +286,20 @@ p_significance.comparisons <- p_significance.slopes
 p_significance.predictions <- p_significance.slopes
 
 
-#' @rdname p_significance
 #' @export
 p_significance.stanreg <- function(x,
                                    threshold = "default",
-                                   effects = c("fixed", "random", "all"),
-                                   component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), # nolint
+                                   effects = "fixed",
+                                   component = "location",
                                    parameters = NULL,
                                    verbose = TRUE,
                                    ...) {
-  effects <- match.arg(effects)
-  component <- match.arg(component)
-  params <- insight::get_parameters(x, effects = effects, component = component, parameters = parameters)
+  params <- insight::get_parameters(
+    x,
+    effects = effects,
+    component = component,
+    parameters = parameters
+  )
 
   threshold <- .select_threshold_ps(
     model = x,
@@ -323,14 +331,18 @@ p_significance.blavaan <- p_significance.stanreg
 #' @export
 p_significance.brmsfit <- function(x,
                                    threshold = "default",
-                                   effects = c("fixed", "random", "all"),
-                                   component = c("conditional", "zi", "zero_inflated", "all"),
+                                   effects = "fixed",
+                                   component = "conditional",
                                    parameters = NULL,
                                    verbose = TRUE,
                                    ...) {
-  effects <- match.arg(effects)
-  component <- match.arg(component)
-  params <- insight::get_parameters(x, effects = effects, component = component, parameters = parameters)
+  params <- insight::get_parameters(
+    x,
+    effects = effects,
+    component = component,
+    parameters = parameters,
+    ...
+  )
 
   threshold <- .select_threshold_ps(
     model = x,
@@ -351,6 +363,7 @@ p_significance.brmsfit <- function(x,
   out
 }
 
+
 .p_significance <- function(x, threshold, ...) {
   if (length(threshold) == 1) {
     psig <- max(
@@ -371,6 +384,7 @@ p_significance.brmsfit <- function(x,
   psig
 }
 
+
 # methods ---------------------------
 
 #' @rdname as.numeric.p_direction
@@ -426,6 +440,7 @@ as.double.p_significance <- as.numeric.p_significance
   }
 }
 
+
 #' @keywords internal
 .select_threshold_list <- function(model = NULL, threshold = "default", verbose = TRUE) {
   # If default
@@ -446,6 +461,8 @@ as.double.p_significance <- as.numeric.p_significance
   threshold
 }
 
+
+#' @keywords internal
 .check_list_range <- function(range, params, larger_two = FALSE) {
   # if we have named elements, complete list
   named_range <- names(range)
