@@ -1,4 +1,4 @@
-print_data_frame <- function(x, digits) {
+.print_data_frame <- function(x, digits) {
   out <- list(x)
   names(out) <- "fixed"
 
@@ -14,34 +14,37 @@ print_data_frame <- function(x, digits) {
     if (anyNA(x$split)) {
       x$split[is.na(x$split)] <- "{other}"
     }
-    out <- lapply(split(x, f = x$split), function(i) {
-      datawizard::data_remove(i, c("split", "Component", "Effects"), verbose = FALSE)
-    })
+    out <- lapply(
+      split(x, f = x$split),
+      datawizard::data_remove,
+      select = c("split", "Component", "Effects"),
+      verbose = FALSE
+    )
   }
 
   for (i in names(out)) {
     header <- switch(i,
-      "conditional" = ,
-      "fixed_conditional" = ,
-      "fixed" = "# Fixed Effects (Conditional Model)",
-      "fixed_sigma" = "# Sigma (fixed effects)",
-      "sigma" = "# Sigma (fixed effects)",
-      "zi" = ,
-      "zero_inflated" = ,
-      "fixed_zero_inflated" = ,
-      "fixed_zi" = "# Fixed Effects (Zero-Inflated Model)",
-      "random" = ,
-      "random_conditional" = "# Random Effects (Conditional Model)",
-      "random_zero_inflated" = ,
-      "random_zi" = "# Random Effects (Zero-Inflated Model)",
-      "smooth_sd" = ,
-      "fixed_smooth_sd" = "# Smooth Terms",
+      conditional = ,
+      fixed_conditional = ,
+      fixed = "# Fixed Effects (Conditional Model)",
+      fixed_sigma = "# Sigma (fixed effects)",
+      sigma = "# Sigma (fixed effects)",
+      zi = ,
+      zero_inflated = ,
+      fixed_zero_inflated = ,
+      fixed_zi = "# Fixed Effects (Zero-Inflated Model)",
+      random = ,
+      random_conditional = "# Random Effects (Conditional Model)",
+      random_zero_inflated = ,
+      random_zi = "# Random Effects (Zero-Inflated Model)",
+      smooth_sd = ,
+      fixed_smooth_sd = "# Smooth Terms",
 
       # blavaan
-      "latent" = "# Latent Loading",
-      "residual" = "# Residual Variance",
-      "intercept" = "# Intercept",
-      "regression" = "# Regression",
+      latent = "# Latent Loading",
+      residual = "# Residual Variance",
+      intercept = "# Intercept",
+      regression = "# Regression",
 
       # Default
       paste0("# ", i)
@@ -59,11 +62,15 @@ print_data_frame <- function(x, digits) {
       out[[i]]$Parameter <- gsub("^smooth_sd\\[(.*)\\]", "\\1", out[[i]]$Parameter)
       out[[i]]$Parameter <- gsub("^sds_", "\\1", out[[i]]$Parameter)
       # SD
-      out[[i]]$Parameter <- gsub("(.*)(__Intercept|__zi_Intercept)(.*)", "\\1 (Intercept)\\3", gsub("^sd_(.*)", "SD \\1", out[[i]]$Parameter))
+      out[[i]]$Parameter <- gsub(
+        "(.*)(__Intercept|__zi_Intercept)(.*)",
+        "\\1 (Intercept)\\3",
+        gsub("^sd_(.*)", "SD \\1", out[[i]]$Parameter)
+      )
       # remove ".1" etc. suffix
       out[[i]]$Parameter <- gsub("(.*)(\\.)(\\d)$", "\\1 \\3", out[[i]]$Parameter)
       # remove "__zi"
-      out[[i]]$Parameter <- gsub("__zi", "", out[[i]]$Parameter)
+      out[[i]]$Parameter <- gsub("__zi", "", out[[i]]$Parameter, fixed = TRUE)
     }
 
     if (length(out) > 1) {
